@@ -1684,7 +1684,7 @@ class XBoardProtocol(EngineProtocol):
                 increment = limit.white_inc if board.turn else limit.black_inc
                 if limit.remaining_moves or increment:
                     base_mins, base_secs = divmod(int(limit.white_clock if board.turn else limit.black_clock), 60)
-                    engine.send_line("level {} {}:{02d} {}".format(limit.remaining_moves or 0, base_mins, base_secs, increment))
+                    engine.send_line("level {} {}:{:02d} {}".format(limit.remaining_moves or 0, base_mins, base_secs, increment))
 
                 if limit.nodes is not None:
                     if limit.time is not None or limit.white_clock is not None or limit.black_clock is not None or increment is not None:
@@ -1695,12 +1695,12 @@ class XBoardProtocol(EngineProtocol):
                     elif not engine.features["nps"]:
                         raise EngineError("xboard engine does not support node limits (feature nps=0)")
 
-                    engine.send_line("nps 100")
+                    engine.send_line("nps 1")
                     engine.send_line("st {}".format(int(limit.nodes)))
                 if limit.depth is not None:
                     engine.send_line("sd {}".format(limit.depth))
                 if limit.time is not None:
-                    engine.send_line("st {}".format(int(limit.time * 100)))
+                    engine.send_line("st {}".format(limit.time))
                 if limit.white_clock is not None:
                     engine.send_line("{} {}".format("time" if board.turn else "otim", int(limit.white_clock * 100)))
                 if limit.black_clock is not None:
