@@ -1122,6 +1122,25 @@ def read_game(handle, *, Visitor=GameCreator):
     if line.isspace():
         line = handle.readline()
 
+    if not skipping_game:
+        # Chess variant.
+        headers = managed_headers if headers is None else headers
+        try:
+            VariantBoard = headers.variant()
+        except ValueError as error:
+            visitor.handle_error(error)
+            VariantBoard = chess.Board
+
+        # Initial position.
+        fen = headers.get("FEN", VariantBoard.starting_fen)
+        try:
+            board_stack = [VariantBoard(fen, chess960=headers.is_chess960())]
+        except ValueError as error:
+            visitor.handle_error(error)
+            skipping_game = True
+        else:
+            visitor.visit_board(board_stack[0])
+
     # Fast path: Skip entire game.
     if skipping_game:
         in_comment = False
@@ -1148,23 +1167,6 @@ def read_game(handle, *, Visitor=GameCreator):
         visitor.end_game()
         return visitor.result()
 
-    # Chess variant.
-    headers = managed_headers if headers is None else headers
-    try:
-        VariantBoard = headers.variant()
-    except ValueError as error:
-        visitor.handle_error(error)
-        VariantBoard = chess.Board
-
-    # Initial position.
-    fen = headers.get("FEN", VariantBoard.starting_fen)
-    try:
-        board_stack = [VariantBoard(fen, chess960=headers.is_chess960())]
-    except ValueError as error:
-        visitor.handle_error(error)
-        board_stack = [VariantBoard(chess960=headers.is_chess960())]
-    visitor.visit_board(board_stack[0])
-
     # Parse movetext.
     skip_variation_depth = 0
     while line:
@@ -1204,35 +1206,29 @@ def read_game(handle, *, Visitor=GameCreator):
                 if line:
                     read_next_line = False
                 break
-            elif token == "(" and board_stack[-1].move_stack:
+            elif token == "(":
                 if skip_variation_depth:
                     skip_variation_depth += 1
-                elif visitor.begin_variation() is SKIP:
-                    skip_variation_depth = 1
-                else:
-                    board = board_stack[-1].copy()
-                    board.pop()
-                    board_stack.append(board)
-            elif token == ")" and skip_variation_depth:
-                skip_variation_depth -= 1
-                if not skip_variation_depth:
+                elif board_stack[-1].move_stack:
+                    if visitor.begin_variation() is SKIP:
+                        skip_variation_depth = 1
+                    else:
+                        board = board_stack[-1].copy()
+                        board.pop()
+                        board_stack.append(board)
+            elif token == ")":
+                if skip_variation_depth:
+                    skip_variation_depth -= 1
+                if len(board_stack) > 1:
                     visitor.end_variation()
-            elif token == ")" and len(board_stack) > 1:
-                # Always leave at least the root node on the stack.
-                visitor.end_variation()
-                board_stack.pop()
+                    board_stack.pop()
             elif skip_variation_depth:
                 continue
             elif token.startswith(";"):
                 break
             elif token.startswith("$"):
                 # Found a NAG.
-                try:
-                    nag = int(token[1:])
-                except ValueError as error:
-                    visitor.handle_error(error)
-                else:
-                    visitor.visit_nag(nag)
+                visitor.visit_nag(int(token[1:]))
             elif token == "?":
                 visitor.visit_nag(NAG_MISTAKE)
             elif token == "??":
@@ -1253,6 +1249,7 @@ def read_game(handle, *, Visitor=GameCreator):
                     move = visitor.parse_san(board_stack[-1], token)
                 except ValueError as error:
                     visitor.handle_error(error)
+                    skip_variation_depth = 1
                 else:
                     visitor.visit_move(board_stack[-1], move)
                     board_stack[-1].push(move)
